@@ -1,5 +1,5 @@
 import os
-from six.moves import cPickle
+import cpickle
 
 import sys
 sys.path.append('.')
@@ -14,7 +14,7 @@ for p,n,v in conway_polynomials:
 dstdir = os.path.join('build')
 dst = os.path.join(dstdir, 'conway_polynomials.p')
 if not os.path.exists(dstdir):
-        os.makedirs(dstdir)
+    os.makedirs(dstdir)
 
 with open(dst, 'wb') as f:
-	cPickle.dump(db, f, protocol=2)
+    pickle.dump(db, f, protocol=2)
